@@ -3,12 +3,13 @@ function (y, x = NULL, test = ifelse(is.null(x), "sw", "ks"),
     distribution = "norm", est.arg.list = NULL, alternative = "two.sided", 
     n.classes = NULL, cut.points = NULL, param.list = NULL, estimate.params = ifelse(is.null(param.list), 
         TRUE, FALSE), n.param.est = NULL, correct = NULL, digits = .Options$digits, 
-    exact = NULL, ws.method = "normal scores", warn = TRUE, data.name = NULL, 
-    data.name.x = NULL, parent.of.data = NULL, subset.expression = NULL, 
-    ...) 
+    exact = NULL, ws.method = "normal scores", warn = TRUE, keep.data = TRUE, 
+    data.name = NULL, data.name.x = NULL, parent.of.data = NULL, 
+    subset.expression = NULL, ...) 
 {
-    test <- match.arg(test, c("sw", "sf", "ppcc", "skew", "chisq", 
-        "ks", "ws"))
+    test <- match.arg(test, c("sw", "sf", "ppcc", "ad", "cvm", 
+        "lillie", "skew", "chisq", "ks", "ws", "proucl.ad.gamma", 
+        "proucl.ks.gamma"))
     if (is.null(data.name)) 
         data.name <- deparse(substitute(y))
     y <- as.vector(unlist(y))
@@ -44,9 +45,11 @@ function (y, x = NULL, test = ifelse(is.null(x), "sw", "ks"),
         if (length(x) == 0) 
             stop("All observations in 'x' are NA/Nan/Inf")
     }
-    if (test %in% c("sw", "sf", "ppcc")) {
+    if (test %in% c("sw", "sf", "ppcc", "ad", "cvm", "lillie")) {
         distribution <- check.distribution.args(distribution, 
             check.params = FALSE)$dist.abb
+        if (distribution == "lnorm3" && test != "sw") 
+            stop("When distribution = 'lnorm3' you must set test = 'sw'")
     }
     else if (test == "skew") {
         distribution <- match.arg(distribution, c("norm", "lnorm", 
@@ -66,6 +69,9 @@ function (y, x = NULL, test = ifelse(is.null(x), "sw", "ks"),
         distribution <- check.da.list$dist.abb
         n.dist.params <- check.da.list$n.dist.params
     }
+    else if (test %in% c("proucl.ad.gamma", "proucl.ks.gamma")) {
+        distribution <- match.arg(distribution, c("gamma", "gammaAlt"))
+    }
     if (test == "chisq") {
         not.miss.n.classes <- !missing(n.classes) & !is.null(n.classes)
         not.miss.cut.points <- !missing(cut.points) & !is.null(cut.points)
@@ -77,15 +83,24 @@ function (y, x = NULL, test = ifelse(is.null(x), "sw", "ks"),
         alternative <- "greater"
     else alternative <- match.arg(alternative, c("two.sided", 
         "less", "greater"))
-    if (test %in% c("sw", "sf", "ppcc") & !(distribution %in% 
-        c("norm", "lnorm", "lnormAlt", "lnorm3", "zmnorm", "zmlnorm", 
-            "zmlnormAlt"))) {
+    if (test %in% c("sw", "sf", "ppcc", "ad", "cvm", "lillie") & 
+        !(distribution %in% c("norm", "lnorm", "lnormAlt", "lnorm3", 
+            "zmnorm", "zmlnorm", "zmlnormAlt"))) {
+        efcn <- paste("e", distribution, sep = "")
         if (EnvStats::Distribution.df[distribution, "Type"] != 
-            "Continuous") 
-            stop(paste("When test=", test, ", the argument 'distribution'", 
-                " must indicate a continuous distribution", sep = ""))
+            "Continuous" || !exists(efcn, where = "package:EnvStats")) 
+            stop(paste("When test=", test, ", the argument 'distribution' ", 
+                "must indicate a continuous distribution, and ", 
+                "there must exist a function to estimate the parameters", 
+                sep = ""))
         test.name <- paste(test, "GeneralGofTest", sep = "")
     }
+    else if (test == "proucl.ad.gamma") {
+        test.name <- "adGammaProUCLGofTest"
+    }
+    else if (test == "proucl.ks.gamma") {
+        test.name <- "ksGammaProUCLGofTest"
+    }
     else test.name <- paste(test, "GofTest", sep = "")
     if (test == "ks") {
         if (is.null(x)) 
@@ -98,19 +113,25 @@ function (y, x = NULL, test = ifelse(is.null(x), "sw", "ks"),
             data.name.y = data.name)
     }
     arg.list <- switch(test.name, swGofTest = , sfGofTest = , 
-        ppccGofTest = , swGeneralGofTest = , sfGeneralGofTest = , 
-        ppccGeneralGofTest = list(x = y, distribution = distribution, 
-            est.arg.list = est.arg.list), skewGofTest = list(x = y, 
-            distribution = distribution, est.arg.list = est.arg.list, 
-            alternative = alternative), chisqGofTest = list(x = y, 
-            n.classes = n.classes, cut.points = cut.points, distribution = distribution, 
-            param.list = param.list, estimate.params = estimate.params, 
-            est.arg.list = est.arg.list, n.param.est = n.param.est, 
-            correct = correct, digits = digits), ksGofTest = ks.arg.list, 
-        wsGofTest = list(x = y, method = ws.method, alternative = alternative))
+        ppccGofTest = , adGofTest = , cvmGofTest = , lillieGofTest = , 
+        swGeneralGofTest = , sfGeneralGofTest = , ppccGeneralGofTest = , 
+        adGeneralGofTest = , cvmGeneralGofTest = , lillieGeneralGofTest = list(x = y, 
+            distribution = distribution, est.arg.list = est.arg.list), 
+        skewGofTest = list(x = y, distribution = distribution, 
+            est.arg.list = est.arg.list, alternative = alternative), 
+        chisqGofTest = list(x = y, n.classes = n.classes, cut.points = cut.points, 
+            distribution = distribution, param.list = param.list, 
+            estimate.params = estimate.params, est.arg.list = est.arg.list, 
+            n.param.est = n.param.est, correct = correct, digits = digits), 
+        ksGofTest = ks.arg.list, wsGofTest = list(x = y, method = ws.method, 
+            alternative = alternative), adGammaProUCLGofTest = , 
+        ksGammaProUCLGofTest = list(x = y, distribution = distribution))
     ret.list <- do.call(test.name, args = arg.list)
+    if (!keep.data) {
+        ret.list <- ret.list[names(ret.list) != "data"]
+        oldClass(ret.list) <- "gof"
+    }
     ret.list$data.name <- c(data.name.x, data.name)
-    names(ret.list$data) <- ret.list$data.name
     if (!is.null(parent.of.data)) 
         ret.list$parent.of.data <- parent.of.data
     if (!is.null(subset.expression)) 
@@ -121,7 +142,6 @@ function (y, x = NULL, test = ifelse(is.null(x), "sw", "ks"),
     else {
         bad.obs <- bad.obs.y
     }
-    if (any(bad.obs) > 0) 
-        ret.list$bad.obs <- bad.obs
+    ret.list$bad.obs <- bad.obs
     ret.list
 }
